<?php
/**
 * This Software is the property of Data Development and is protected
 * by copyright law - it is NOT Freeware.
 *
 * Any unauthorized use of this software without a valid license
 * is a violation of the license agreement and will be prosecuted by
 * civil and criminal law.
 *
 * http://www.shopmodule.com
 *
 * @copyright  D Data Development, Thomas Dartsch
 * @author    D Data Development <support@shopmodule.com>
 * @link      http://www.oxidmodule.com
 */

define('FILETYPE_GIF', 1);
define('FILETYPE_JPG', 2);
define('FILETYPE_PNG', 3);

if (false == function_exists("getShopBasePath")) {
    /**
     * Returns shop base path.
     *
     * @return string
     */
    function getShopBasePath()
    {
        return realpath(dirname(__FILE__) . '/../../../..') . '/';
    }
}

/** @var $oModule oxmodule */
$oModule = oxNew('oxmodule');

if ($oModule->load('d3watermark') && $oModule->isActive()) {

    /**
     * @return d3watermark
     */
    function d3GetWatermarkHandler()
    {
        $oWm = oxNew('d3watermark');

        return $oWm->getInstance();
    }

    /**
     * required, because gif image generator don't call "copyAlteredImage" method
     *
     * @param $sSrc
     * @param $sTarget
     * @param $iNewWidth
     * @param $iNewHeight
     * @param $iOriginalWidth
     * @param $iOriginalHeigth
     * @param $iGDVer
     *
     * @return bool
     */
    function resizeGif($sSrc, $sTarget, $iNewWidth, $iNewHeight, $iOriginalWidth, $iOriginalHeigth, $iGDVer)
    {
        $rDestinationImage = imagecreate($iNewWidth, $iNewHeight);
        $rSourceImage      = imagecreatefromgif($sSrc);
        $iTransparentColor = imagecolorresolve($rSourceImage, 255, 255, 255);
        $iFillColor        = imagecolorresolve($rDestinationImage, 255, 255, 255);
        imagefill($rDestinationImage, 0, 0, $iFillColor);
        imagecolortransparent($rSourceImage, $iTransparentColor);

        $rSourceImage = d3GetWatermarkHandler()->d3AddWatermark($rSourceImage, $sTarget);

        if ($iGDVer == 1) {
            imagecopyresized(
                $rDestinationImage,
                $rSourceImage,
                0,
                0,
                0,
                0,
                $iNewWidth,
                $iNewHeight,
                $iOriginalWidth,
                $iOriginalHeigth
            );
        } else {
            imagecopyresampled(
                $rDestinationImage,
                $rSourceImage,
                0,
                0,
                0,
                0,
                $iNewWidth,
                $iNewHeight,
                $iOriginalWidth,
                $iOriginalHeigth
            );
        }

        imagecolortransparent($rDestinationImage, $iFillColor);
        imagegif($rDestinationImage, $sTarget);
        imagedestroy($rDestinationImage);
        imagedestroy($rSourceImage);

        return true;
    }

    /**
     * @param $sDestinationImage
     * @param $rSourceImage
     * @param $iNewWidth
     * @param $iNewHeight
     * @param $aImageInfo
     * @param $sTarget
     * @param $iGDVersion
     *
     * @return bool
     */
    function copyAlteredImage($sDestinationImage, $rSourceImage, $iNewWidth, $iNewHeight, $aImageInfo, $sTarget, $iGDVersion)
    {
        d3GetWatermarkHandler()->setImageInfo($aImageInfo);
        d3GetWatermarkHandler()->setGDVersion($iGDVersion);

        $rSourceImage = d3GetWatermarkHandler()->d3AddWatermark($rSourceImage, $sTarget);

        if ($iGDVersion == 1) {
            $blSuccess = imagecopyresized(
                $sDestinationImage,
                $rSourceImage,
                0,
                0,
                0,
                0,
                $iNewWidth,
                $iNewHeight,
                $aImageInfo[0],
                $aImageInfo[1]
            );
        } else {
            $blSuccess = imagecopyresampled(
                $sDestinationImage,
                $rSourceImage,
                0,
                0,
                0,
                0,
                $iNewWidth,
                $iNewHeight,
                $aImageInfo[0],
                $aImageInfo[1]
            );
        }

        return $blSuccess;
    }

    /**
     * @param $sSrc
     * @param $sTarget
     * @param $iWidth
     * @param $iHeight
     * @param $iOrigWidth
     * @param $iOrigHeigth
     *
     * @return array
     */
    function checkSizeAndCopy($sSrc, $sTarget, $iWidth, $iHeight, $iOrigWidth, $iOrigHeigth)
    {
        list($iNewWidth, $iNewHeight) = calcImageSize($iWidth, $iHeight, $iOrigWidth, $iOrigHeigth);

        return array($iNewWidth, $iNewHeight);
    }
}

include_once getShopBasePath() . "core/utils/oxpicgenerator.php";
